#
# spec file for package gh
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define goflags "-buildmode=pie -trimpath -mod=vendor -modcacherw"
%define sname cli
Name:           gh
Version:        2.20.2
Release:        bp155.1.7
Summary:        The official CLI for GitHub
License:        MIT
Group:          Development/Tools/Other
URL:            https://cli.github.com/
Source0:        https://github.com/cli/cli/archive/v%{version}.tar.gz#/%{sname}-%{version}.tar.gz
Source1:        vendor.tar.gz
# Completions
BuildRequires:  fish
BuildRequires:  zsh
# Build/Test requirements
BuildRequires:  git-core
BuildRequires:  golang(API) >= 1.18
Requires:       git-core

%description
Official CLI client for GitHub written in Go

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Development/Tools/Other
Requires:       %{name} = %{version}
Requires:       bash-completion
%if 0%{?suse_version} == 1315
Supplements:    packageand(gh:bash-completion)
%else
Supplements:    (gh and bash-completion)
%endif
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Group:          Development/Tools/Other
Requires:       %{name} = %{version}
%if 0%{?suse_version} == 1315
Supplements:    packageand(gh:zsh)
%else
Supplements:    (gh and zsh)
%endif
BuildArch:      noarch

%description zsh-completion
ZSH command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          Development/Tools/Other
Requires:       %{name} = %{version}
%if 0%{?suse_version} == 1315
Supplements:    packageand(gh:fish)
%else
Supplements:    (gh and fish)
%endif
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -n %{sname}-%{version} -a 1
# Upstream decided to tweak Makefile for easier cross-compiling. But the tweak
# overrides variables so we need to remove them to pass GOFLAGS.
sed -i 's/GOOS= GOARCH= GOARM= GOFLAGS= CGO_ENABLED=//g' Makefile

%build
export GOFLAGS="-buildmode=pie -trimpath -mod=vendor -modcacherw -ldflags=-linkmode=external"
%if 0%{?suse_version} == 1315
make %{?_smp_mflags} GH_VERSION="v%{version}" bin/gh manpages
%else
%make_build GH_VERSION="v%{version}" bin/gh manpages
%endif

%install
bin/gh completion -s bash | install -Dm644 /dev/stdin \
       %{buildroot}%{_datadir}/bash-completion/completions/gh
bin/gh completion -s zsh  | install -Dm644 /dev/stdin \
       %{buildroot}%{_datadir}/zsh/site-functions/_gh
bin/gh completion -s fish | install -Dm644 /dev/stdin \
       %{buildroot}%{_datadir}/fish/vendor_completions.d/gh.fish

install -Dm755 bin/gh %{buildroot}%{_bindir}/gh
install -d %{buildroot}%{_mandir}/man1/
cp share/man/man1/* %{buildroot}%{_mandir}/man1

%check
GOFLAGS=%{goflags} make test

%files
%doc README.md
%license LICENSE
%{_bindir}/gh
%{_mandir}/man1/*

%files bash-completion
%{_datadir}/bash-completion/completions/gh

%files zsh-completion
%{_datadir}/zsh/site-functions/_gh

%files fish-completion
%{_datadir}/fish/vendor_completions.d/gh.fish

%changelog
* Tue Nov 29 2022 Emily Roberts <nopeinomicon@posteo.net>
- Update to 2.20.2
  https://github.com/cli/cli/releases
  * Update security policy by @maclarel in #6587
  * Fix listing repositories for a named GitHub user by @mislav in #6608
  * Fix commands not properly refreshing the terminal screen by @samcoe in #6607
* Fri Nov 11 2022 chris@computersalat.de
- Update to 2.20.0
  https://github.com/cli/cli/releases
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 2.14.2:
  * Remove accidental caching from `repo list` and other commands
  * strip whitespace when adding topics
  * Set blank headers so they are not automatically resolved by go-gh (#5935)
  * Post go-gh integration cleanup (#5933)
* Wed Jul 13 2022 chris@computersalat.de
- Update to 2.14.1
  https://github.com/cli/cli/releases
  * What's Changed
  - auth login/refresh: Fix auth token not being present in login and refresh flows @samcoe in #5928
- fix spec
  * add missing Group
* Mon Jul 11 2022 chris@computersalat.de
- Update to 2.13.0
  https://github.com/cli/cli/releases
  * What's New
  - Add pr merge --match-head-commit flag by @ffalor in #5692
  - Add codespace create --retention-period flag by @gdomingu in #5825
  - Add codespace list/stop/delete --org management capabilities for organization administrators by @greggroth and @8Gitbrix in #5807 #5812 #5827
  - codespace ssh: automatically generate SSH keys by @cmbrose in #5752
  - codespace create: notify user when codespace usage is covered by an organization by @jshorty in #5816
  - secret set: allow setting Codespace repository secrets by @greggroth in #5802
  - Add Windows ARM precompiled binary and support arm64 extensions by @azchohfi in #5715
  * What's Changed
  - Improve gh auth help message based on CI environment by @spenserblack in #5781
  - Fix determining the path to the gh executable under Homebrew by @mislav in #5822
  - pr create: clear filter when selecting from a list in interactive mode by @wilhelmeek in #5841
  - repo fork: raise error if attempting to fork own repository by @jf-delineate in #5794
  - Simplify codespace picker by @greggroth in #5826
  - Bump github.com/stretchr/testify from 1.7.3 to 1.7.4 by @dependabot in #5833
* Thu May 26 2022 stimut@gmail.com
- Update to version 2.11.3:
  * Bugfix: Retention period is being sent to the API as 0 (#5706)
  * Fix Cobra completion output going to stdout
  * Fix --version flag printing to stdout
  * Add --upstream-remote-name flag to gh replo clone (#5619)
  * Parallelize `label clone` (#5687)
  * Stop bumping winget manifest as part of release automation (#5699)
  * Write Cobra deprecation messages to stderr
  * Bump goreleaser/goreleaser-action from 2 to 3
  * Clarify that ShowResponseHeaders includes status line
  * Fix owner qualifier for search queries (#5693)
  * Add `--pattern` field to `run download` (#5539)
  * add `include-all-branches` flag to `repo create` (#5537)
  * Add ability to set title for ssh key in auth login (#5524)
  * Always clear screen when watching PR checks (#5678)
  * Fix `label clone` to pass orderBy (#5675)
  * pr create: ensure clear error when `--body` is missing in nonTTY mode
  * Allow passing full extension name (#5464)
  * Fixing #5624 - Removing unneeded hint and additional new line (#5642)
  * Extract feature detection package (#5494)
  * dont need assignment
  * issue view: ensure loading indicator is stopped when a prompt is shown (#5641)
  * Change int to uint64 for large fields (#5651)
  * filter out internal ports from gh cs ports list
  * Support rerunning Actions runs with debug logging (#5594)
  * Allow nil to truncate template function
  * Support and favor delete for secrets (#5617)
  * Fix whitespace in search prs examples (#5650)
  * Fix struct field tag (#5649)
  * Replace uses of strings.Title (#5623)
  * Removing confusing user search text (#5620)
  * Re-enable linters now that golangci-lint has been updated (#5615)
* Wed May 11 2022 rombert@apache.org
- Update to version 2.10.1:
  * Hide retention-period flag (#5607)
  * Merge pull request #5504 from greggroth/gregg/retention-period
  * repo clone: document the upstream remote (#5466)
  * auth: respect GH_BROWSER, `browser` config, avoid opening non-HTTP URLs
  * repo list: add `--visibility internal` filter (#5564)
  * Fix nil pointer exception in codespace selection
  * add devcontainer (#5592)
  * Ensure stable presentation of FORBIDDEN errors
  * :nail_care: optimize fetches
  * Ignore FORBIDDEN errors for `gh status`
  * status: exclude results from archived repositories
  * Add `exclude-drafts` flag to `gh release list`
  * Upgrade to go 1.18 (#5542)
  * Update order
  * Handle star in display name
  * Dis-ambiguate "currentBranch"
  * :nail_care:
  * Add `--json` support to `label list` (#5567)
  * Add Display Name to the list command
  * Remove empty return
  * Fix non-working `gh issue view` usage example (#5563)
  * Fix: 5501 - Added examples of negated qualifiers to search commands (#5562)
  * Add label list sorting and delete command (#5503)
  * Add the ability to pass teams to `review-requested` (#5538)
  * Document linux distribution updating  (#5531)
  * Consistent version format in version upgrade notice
  * Fix grammar in `repo create` prompt (#5557)
  * issue comment: support quotes and arguments in EDITOR value
  * Remove mention of function
  * Use named return values
  * Use safeClose instead of Close
  * Update auth error message
  * Remove `Stringer` from `ghrepo.Interface` (#5536)
  * Bump github.com/google/go-cmp from 0.5.7 to 0.5.8 (#5533)
  * Add progress indicator to `gist create` (#5526)
  * Clarify `label edit --name` switch (#5525)
  * Bump github.com/cpuguy83/go-md2man/v2 from 2.0.1 to 2.0.2
  * Add autocomplete descriptions for aliases and extensions (#5447)
  * Replace ioutil with io and os (#5498)
  * Add `label edit` command (#5519)
  * Properly handle issue and pr state options when building search queries (#5513)
  * Add `label clone` command (#5452)
  * Don't error on list commands when no results found (#5479)
  * refactor merge command
  * Bump github/codeql-action from 1 to 2
  * Avoid crash when deleting gist with no owner
  * Add context to errors
  * Resolve feedback
  * Remove function return
  * PR feedback
  * Fix displayed header for search prs command (#5488)
  * add ls alias to gh repo list (#5480)
  * Clarify session helper
  * Clean up more errors
  * Clean up errors
  * Fix -c option
  * Print JupyterLab URL
  * Fix name of RPC service
  * Clean up Jupyter code
  * Fix tests
  * Final copy and behavior update for prompt
  * go fmt
  * Change the way we parse list-devcontainers response
  * Fix tests
  * Change some copy per product's suggestions
  * Refactor liveshare setup to a new function
  * Clean up code
  * Fix RPC call
  * Add cs jupyter
  * Rename test
  * Add interactive prompt to choose from list of available devcontainer files
  * Add devcontainer_path API param as an option
* Thu Mar 10 2022 chris@computersalat.de
- Update to 2.5.2
  https://github.com/cli/cli/releases
  * Other Bugfixes
  - Fix HexToRGB panic by @markphelps in #5247
  * Other Changes
  - Support filtering PRs authored by GitHub Apps by @joshmgross in #5180
  - gh auth login: added flags to partially automate flow by @jonathan-enf in #5158
  - Codespaces Create: Allow Accepting Permissions by @markphelps in #5234
  * Development & Docs
  - Bump github.com/itchyny/gojq from 0.12.6 to 0.12.7 by @dependabot in #5263
  - Misc. docs improvements by @mislav in #5223
  - Use StringEnumFlag helper in more places by @mislav in #5221
  - Change how gh-cli is installed on fedora by @Hanjingxue-Boling in #5204
- updated vendor.tar.gz
* Thu Feb 17 2022 <chris@computersalat.de>
- Update to 2.5.1
  https://github.com/cli/cli/releases
  * New features
  - Add display name to codespaces prompts and JSON output by @veverkap in #5044
  - Add pr checks --watch flag by @endorama in #4519
  * Fixes
  - auth login --with-token: fix authenticating git operations by @mislav in #5186
  - release create: respect discussion category when creating a release with assets by @k-jun in #5019
  - gist create: handle Windows-style file paths by @joshmgross in #5173
  - release create: warn about unpushed local git tag by @samcoe in #5104
  - Ignore EPIPE errors when writing to a closed pager by @mislav in #5143
  - Rotate our Windows code-signing certificates by @mislav in #5196
- updated vendor.tar.gz
* Tue Dec 28 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 2.4.0
  - Add repo edit command by @g14a in gh#cli/cli#4318
  - release create: add --generate-notes functionality by @Sixeight in gh#cli/cli#4467
  - release create: add interactive mode to choose a tag name by @sguzmanm in gh#cli/cli#4525
  - pr merge: allow editing commit subject by @cristiand391 in gh#cli/cli#3344
  - secret set: allow importing secrets from a dotenv file by @lpessoa in gh#cli/cli#4534
  - run list/view: add --json export functionality by @cristiand391 in gh#cli/cli#3869
  - Refresh man pages by @mislav in gh#cli/cli#4939
  - Add installation instructions for pkgsrc by @bsiegert in gh#cli/cli#4931
  - pr view: ensure that PR reviews are always rendered in --comments mode by @mislav in gh#cli/cli#4848
  - api: handle HTTP 409 error message from the server by @mislav in gh#cli/cli#4862
  - issue edit: fix race condition when updating labels by @despreston in gh#cli/cli#4861
  - browse: support --commit with the repo override flag by @bchadwic in gh#cli/cli#4845
  - repo create: fix printing repo URL in no-TTY mode by @mislav in gh#cli/cli#4904
  - repo sync: use the new merge-upstream API if available by @mislav in gh#cli/cli#4942
  - run: display and treat "Cancelled" status as a failure by @bchadwic in gh#cli/cli#4850
  - extension upgrade: an already up-to-date extension should not a produce a failure by @tisonkun in gh#cli/cli#4857
  - Avoid showing non-open PRs as related to the default branch by @AyushRawal in gh#cli/cli#4285
  - git remotes: fix treating ssh.github.com as a github.com host by @mislav in gh#cli/cli#4938
  - Bump Cobra to 1.3.0 for improved completion support by @mislav in gh#cli/cli#4936
  - Bump spinner to 1.18.0 by @mislav in gh#cli/cli#4937
* Mon Dec 20 2021 Emily Roberts <nopeinomicon@posteo.net>
- Change issue references in the changelog to proper OBS abbreviations
* Sat Dec 18 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 2.3.0
  * Add support for precompiled extensions
  - fix binary extensions on windows by @vilmibm in gh#cli/cli#4717
  - binary extension migration by @vilmibm in gh#cli/cli#4588
  - make extension create binary aware by @vilmibm in gh#cli/cli#4718
  - Extensions create nail_care by @mislav in gh#cli/cli#4802
  * rewrite gh repo create by @meiji163 @pxrth9 in gh#cli/cli#4578
  - gh repo create will no longer automatically add a git remote to the local git repository in the current directory. To emulate old behavior when inside a local git repository, use gh pr create --source ..
  - gh repo create will only prompt interactively when run with no arguments. Otherwise, all arguments should be passed explicitly.
  * Fix codespace code command under WSL by @mislav in gh#cli/cli#4747
  * Inherit API endpoint configuration from the Codespaces environment by @marwan-at-work in gh#cli/cli#4723
  * Remove the default value from idle-timeout by @reybard in gh#cli/cli#4756
  * Support listing and removing user Codespaces secrets by @joshmgross in gh#cli/cli#4714
  * Support setting user Codespaces secrets by @joshmgross in gh#cli/cli#4699
  * Add idle_timeout_minutes as possible cs create param by @reybard in gh#cli/cli#4741
  * Adds a timeout context to the ssh waiter to prevent indefinite hanging by @reybard in gh#cli/cli#4635
  * Rename errors from Live Share to generic codespace by @josebalius in gh#cli/cli#4705
  * Add prebuild availability status to create codespaces by @adnamalin in gh#cli/cli#4737
  * Add command gh auth setup-git for setting up gh-cli as git cred helper by @despreston in gh#cli/cli#4246
  * Add gh config list by @meiji163 in gh#cli/cli#4729
  * Add new flag gh secret set --no-store to print the encoded secret by @sguzmanm in gh#cli/cli#4423
  * Adding release download for.zip and .tar.gz archives by @lpessoa in gh#cli/cli#4489
  * gh repo rename by @pxrth9 in gh#cli/cli#4450
  * Ignore scope suggestions for http 422 by @despreston in gh#cli/cli#4809
  * pr diff color output fixes by @mislav in gh#cli/cli#4833
  * PR merge should, after switching branches, pull by @pxrth9 in gh#cli/cli#4748
  * Don't swallow duplicate SSH key error by @despreston in gh#cli/cli#4807
  * gh pr merge fails to delete remote branch if $PWD is not a git repository by @pxrth9 in gh#cli/cli#4769
  * Fix up bug in RemoveEntry and add tests for config_map by @samcoe in gh#cli/cli#4784
  * Escape workflow information when generating URLs by @samcoe in gh#cli/cli#4760
  * Confirm name change before creating a repo with special characters by @bchadwic in gh#cli/cli#4562
  * encode gh browse output URL by @bchadwic in gh#cli/cli#4663
  * add base repo resolution to gh repo archive by @meiji163 in gh#cli/cli#4654
  * add base repo resolution to gh repo delete by @meiji163 in gh#cli/cli#4655
  * Fix stack overflow in AddJSONFlags by @rsteube in gh#cli/cli#4614
  * Fix rendering issue in "formatting" help topic by @pbnj in gh#cli/cli#4661
  * fix branch flag on browse within dir by @bstncartwright in gh#cli/cli#4676
  * Generate Go 1.17-style go:build directives by @mislav in gh#cli/cli#4838
  * Bump github.com/itchyny/gojq from 0.12.5 to 0.12.6 by @dependabot in gh#cli/cli#4832
  * some automation by @vilmibm in gh#cli/cli#4810
  * Improve issue view re: overfetching, PR support by @mislav in gh#cli/cli#4803
  * Improve queries in issue commands: no overfetching, support PR arguments by @mislav in gh#cli/cli#4794
  * Bump github.com/mattn/go-colorable from 0.1.11 to 0.1.12 by @dependabot in gh#cli/cli#4804
  * Replace shurcool/graphql with cli/shurcool-graphql by @samcoe in gh#cli/cli#4750
  * update help for magic type conversion gh#cli/cli#4365 by @signalwerk in gh#cli/cli#4434
  * fix angle brackets in man pages by @meiji163 in gh#cli/cli#4752
  * Overhaul manual pages for the web by @mislav in gh#cli/cli#4675
  * Fix CODEOWNERS for codespaces by @mislav in gh#cli/cli#4728
  * Don't use gpg in Debian instruction by @TobiX in gh#cli/cli#4610
  * Bump bluemonday to silence the security alert by @mislav in gh#cli/cli#4607
- Changes from 2.2.0
  * Support for GitHub Codespaces
  * Add repo delete command by @meiji163 in gh#cli/cli#4451
  * Add run cancel command by @cristiand391 in gh#cli/cli#3833
  * Add gpg-key management commands by @owenvoke in gh#cli/cli#3822
  * Support logging in to github.localhost by @joshmgross in gh#cli/cli#4523
  * browse: respect the current working directory for file arguments by @bchadwic in gh#cli/cli#4007
  * release create: respect the --draft flag in interactive mode by @Sixeight in gh#cli/cli#4542
  * api: avoid repeating GET parameters when paginating by @mislav in gh#cli/cli#4559
  * The progress spinner is now visible against a light background gh#cli/cli#4556
  * Dispatch binary extensions directly by @vilmibm in gh#cli/cli#4568
  * Fix copy/paste mistake in docs by @stdtom in gh#cli/cli#4582
- Changes from 2.1.0
  * Add repo archive command by @pxrth9 & @meiji163 in gh#cli/cli#4410
  * Add support for precompiled extensions by @vilmibm in gh#cli/cli#4308 gh#cli/cli#4373
  * If an extension repository publishes Releases with uploaded binary assets named with a suffix formatted like {OS}-{ARCH} (e.g. linux-amd64), the matching binary will be downloaded and installed as the extension instead of cloning the code from the extension repository.
  * pr list: add --draft, --non-draft, and --head filters by @SiarheiFedartsou in gh#cli/cli#4316 gh#cli/cli#4279
  * pr diff: add --patch flag by @m4ver1k in gh#cli/cli#4460
  * browse: add --commit flag to open the permalink for the latest commit by @bchadwic in gh#cli/cli#3950
  * api: add docs hint on how to use use stdin by @rethab in gh#cli/cli#4291
  * pr checks/run: revised "pending" and "skipped" symbols by @bchadwic in gh#cli/cli#4090
  * pr checkout: also set pushRemote for new branches by @RasmusWL in gh#cli/cli#4363
  * extension list: speed up checking for updates by @samcoe in gh#cli/cli#4396
  * extension install: document installing using a full URL by @wrslatz in gh#cli/cli#4271
  * extension create: use /usr/bin/env bash instead of /bin/bash in generated shebang by @kidonng in gh#cli/cli#4203
  * browse: add support for line ranges browse by @despreston in gh#cli/cli#4253
  * browse: fix markdown files with line ranges by @andrewhsu in gh#cli/cli#4310
  * repo garden: use the x/term package instead of shelling out to stty by @mislav in gh#cli/cli#4214
  * repo sync: allow user input for git fetch by @samcoe in gh#cli/cli#4328
  * repo create: avoid swallowing error from a prompt by @mislav in gh#cli/cli#4331
  * Skip authentication requirement for internal completion commands by @cuonglm in gh#cli/cli#4189
  * Add quotes around @me in documentation to ensure examples work in PowerShell by @Jernik in gh#cli/cli#4239
  * Suggest to re-authenticate to fix "SAML enforcement" error by @mislav in gh#cli/cli#4241
  * Print warning when limit exceeds search API maximum by @despreston in gh#cli/cli#3967
  * Add git+https to the list of supported git remote URL protocols by @danburzo in gh#cli/cli#4347
  * Fix detecting the current gh executable in PATH by @wilso199 in gh#cli/cli#4243
  * Bump Survey library to fix the "Unexpected escape sequence" error by @mislav in gh#cli/cli#4405
  * Warn about missing OAuth scopes when printing HTTP 4xx errors by @mislav in gh#cli/cli#4513
* Fri Dec 10 2021 Emily Roberts <nopeinomicon@posteo.net>
- Fix boogh#cli/cli#1192421 - Changed git dependency to only git-core
* Thu Sep  2 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 2.0.0
  * Support for command extensions
  * Display label colors in issue list output gh#cli/cli#4106
  * Add tablerow/tablerender template functions for rendering data as tables gh#cli/cli#3519
  * Add GH_FORCE_TTY to enable terminal-style output even when redirected gh#cli/cli#4146
  * Add repo sync command to sync a branch with its upstream state gh#cli/cli#3813
  * Add pr checkout --branch flag to control the branch name gh#cli/cli#4005
  * Add release create --discussion-category flag gh#cli/cli#4003
  * Add config set browser option and GH_BROWSER environment variable gh#cli/cli#3992
  * Add repo list --topic filter gh#cli/cli#4136
  * Add PowerShell instructions to completion help gh#cli/cli#4114
  * Improve accessibility of interactive select menus gh#cli/cli#4172
  * Improve detection of truecolor terminal capabilities gh#cli/cli#4106
  * Avoid wrapping issues in powershell.exe gh#cli/cli#4106
  * Detect missing git and abort early during auth login flow gh#cli/cli#4109
  * Fix HTTP 502 error printing from GraphQL responses gh#cli/cli#4154
  * Require Go 1.16+ gh#cli/cli#4175
  * Remove backwards compatibility with homedir library for config files gh#cli/cli#4145
* Sat Aug  7 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 1.14.0
  * Improve shell completion gh#cli/cli#4028
  - Enable --json flag completion with multiple comma-separated fields
  - Add completion for repo create --gitignore flag
  - Add completion for repo create --license flag
  - Switch to Cobra's improved bash completion with descriptions
  - Enable descriptions in PowerShell completion gh#cli/cli#4085
  - Add completion of -R/--repo flag based on available git remotes gh#cli/cli#3942
  * Add pr merge --admin flag to allow admins to force-merge a pull request gh#cli/cli#4071
  * Fix authenticating with GH_ENTERPRISE_TOKEN and GH_HOST environment variables gh#cli/cli#4019
  * Fix labels display in issue list output gh#cli/cli#4079
  * Fix printing certain GraphQL errors gh#cli/cli#4087
* Wed Jul 28 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 1.13.1
  * Release fixes pre-built binaries, changes aren't applicable to this package
- Changes from 1.13.0
  * issue/pr view: output label names in their own color gh#cli/cli#3912
  * Add gh browse --no-browser to only print the URL gh#cli/cli#3943
  * repo create: respect privacy setting when using license/gitignore templates gh#cli/cli#3972
  * repo create: respect repository description when creating from template repository gh#cli/cli#3972
  * repo create --confirm: avoid license/gitignore template prompt gh#cli/cli#3995
  * pr merge --auto: merge immediately if the PR is already mergeable gh#cli/cli#3706
  * pr merge: suggest using --auto when merging is blocked gh#cli/cli#3706
  * Allow using cursor keys in interactive text inputs gh#cli/cli#3980
  * gh run watch --exit-status: correct exit status for completed runs gh#cli/cli#3982
  * Skip auto-migrate of config files when GH_CONFIG_DIR is set gh#cli/cli#4017
  * alias set: add note about double-quoting arguments for Command Prompt users gh#cli/cli#4013
  * Clean up GH_CONFIG_DIR docs gh#cli/cli#4020
- Changes from 1.12.1
  * Fix bug where branchProtectionRule doesn't exist in enterprise 2.22 gh#cli/cli#3922
  * Fix repo create in org with license/ignore gh#cli/cli#3924
- Changes from 1.12.0
  * Added gh browse command
  * Add .gitignore and LICENSE when creating repositories from scratch
  * A new config value http_unix_socket can be configured to a local path to push all traffic over a socket
  * Print help even if logged out gh#cli/cli#3850
  * Add shell completion for the --state flag gh#cli/cli#3877
  * Allow explicitly empty body in issue/pr create gh#cli/cli#3787
  * Increase GH_PAGER precedence gh#cli/cli#3789
  * Fix showing Checks information in pr status gh#cli/cli#3804
  * Update "Accept" header for github.com requests gh#cli/cli#3803
  * Fix setting environment secrets gh#cli/cli#3832
  * Fix gh run download fails on large artifacts due to uint32 limitation gh#cli/cli#3890
  * repo fork: check that --org is not the empty string gh#cli/cli#3807
  * Document installing via Conda package manager gh#cli/cli#3792
  * Fix description for gh secret set --env option gh#cli/cli#3784
  * Add a long command description for secrets remove gh#cli/cli#3786
  * Update documentation for gist create command with default of secret gh#cli/cli#3871
  * fork tests cleanup gh#cli/cli#3809
  * Remove unused method from httpmock package gh#cli/cli#3834
  * Factory cleanup gh#cli/cli#3841
  * Improvements to build script on Windows gh#cli/cli#3846
  * Ensure that tests for command factory never read from user's config gh#cli/cli#3856
* Wed Jun 23 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.11.0:
  * Add support for environment secrets gh#cli/cli#3270 gh#cli/cli#3769 gh#cli/cli#3774
  * run list: add "age" column and columns headers in output gh#cli/cli#3575
  * Add support for XDG Base Directory specification gh#cli/cli#3671 gh#cli/cli#3768 gh#cli/cli#3717
  * Additionally, the default configuration location on Windows is now changed from ~/.config/gh/ to %%AppData%%.
  * Include number alongside the title in issue/pr view gh#cli/cli#3741
* Tue Jun 15 2021 Christian Wittmer <chris@computersalat.de>
- fix build for SLES12
  * fix Supplements: packageand(X:Y)
* Sat May 22 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.10.3:
  * Fix gh pr merge with GitHub Enterprise Server < 3.0 gh#cli/cli#3688
  * Speed up measuring display width of text gh#cli/cli#3668
  * Simplify Debian/Ubuntu installation docs gh#cli/cli#3672
- Changes from 1.10.2:
  * Fix creating Windows directory for gh config gh#cli/cli#3666
* Wed May 19 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.10.1:
  * Fix pr checkout for cross-repository pull requests gh#cli/cli#3663
* Wed May 19 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.10.0:
  - Improvements to JSON exporting
  * Add gh repo list/view --json support gh#cli/cli#3627
  * Add gh release view --json support gh#cli/cli#3656
  * Fixes numerous issues with gh pr list/view --json support gh#cli/cli#3547
  - fetching closed field
  - fetching date fields like createdAt or mergedAt
  - fetching files field
  * Fix exporting milestone field for issues and PRs gh#cli/cli#3529
  * Add commits field to JSON export for PRs gh#cli/cli#3547
  * Show more than 100 comments in gh issue view --json comments gh#cli/cli#3547
  * Add shell completion for valid --json flag values gh#cli/cli#3628
  - New Features
  * Add gh repo fork --org option gh#cli/cli#3611
  * Allow passinggh alias set value via standard input gh#cli/cli#3490
  * Prompt for value in gh secret set gh#cli/cli#3499
  * Update gh api placeholder syntax to {owner}, {repo} to match
    GitHub API documentation gh#cli/cli#3536
  * Extend our package repository to support Ubuntu Hirsute and
    Kali linux gh#cli/cli#3398
  - Fixes
  * Speedup across most gh pr commands gh#cli/cli#3547
  * Fix gh pr operations from GitHub Actions when a PR was added
    as a card to an org project gh#cli/cli#3547
  * Allow deleting local git branch in gh pr close gh#cli/cli#3547
  * Fix showing more than 100 checks in gh pr checks gh#cli/cli#3547
  * Fix viewing and editing draft releases with GitHub Actions token gh#cli/cli#3656
  * Fix Windows path in gh auth status output gh#cli/cli#3491
  * Ignore HTTP 404 error for annotations in gh run watch gh#cli/cli#3517
  * Handle Incorrect function exception for MinTTY users
    (typically in Git Bash) by suggesting switching to Windows Terminal gh#cli/cli#3537
  * Query fewer fields to determine issue status gh#cli/cli#3525
  * Warn about empty contents on gh gist create gh#cli/cli#3578
  * Fix "null" display in colored JSON output gh#cli/cli#3626
  * Fix some docs formatting for the web gh#cli/cli#3648
* Tue Apr 20 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.9.2:
  - Actions Fixes
  * Fix Actions use int64 explicitly in Actions support gh#cli/cli#3432
  * Fix requesting REST sub-resources on GHE gh#cli/cli#3461
  * Fix run view --log when steps have slashes gh#cli/cli#3445
  * Include magic repo resolution magic for gh workflow and gh run gh#cli/cli#3468
  - Other Fixes
  * Fix issue create --web gh#cli/cli#3472
  * Fix detecting PR status when passing branch as arg gh#cli/cli#3351
  * Bump AlecAivazis/survey to fix bug with unicode input gh#cli/cli#3439
  - Development / Docs
  * Increase linter timeout from 1min to 3min gh#cli/cli#3462
  * Remove unused embedded struct gh#cli/cli#3402
  * Add note on supported value types in raw-fields gh#cli/cli#3400
  * linuxbrew details added in linux installation docs. gh#cli/cli#3465
  * Add Funtoo Linux install instructions gh#cli/cli#3438
  * Add Debian install variant without add-apt-repository gh#cli/cli#3419
* Mon Apr 19 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.9.1:
  * Create cache dir
  * Fix whitespace formatting of `issue/pr view` help text
  * Disallow unsupported values for `--json` flag
  * Fix `pr view` tests broken by `createdAt` → `submittedAt` switch
  * Fix assigning null Exporter
  * Tests for GraphQL query builder and JSON exporter
  * Add `gh help formatting` topic & link to it from commands with JSON output
  * Placeholder consistency
  * Minor usage improvements
  * Bump run list limit
  * Annotation fixes
  * Unhide actions commands
  * Incorporate wording feedback
  * Fix small bug with startup_failure conclusion
  * Add note about current branch detection
- Prevent Makefile from overriding variables
- Enable tests
* Tue Apr 13 2021 Martin Pluskal <mpluskal@suse.com>
- Supplement bash-completion instead of bash
* Mon Apr 12 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.8.1:
  * Fix pr status/checks crash with unrecognized statuse from
    the server(gh#cli/cli#3336)
  * Fix repo fork --clone not cloning an existing fork locally
    when running non-interactively(gh#cli/cli#3334)
  * Fix commands not respecting default hostname from GH_HOST(gh#cli/cli#3347)
- Create subpackages for completions
* Sun Mar  7 2021 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * see https://github.com/cli/cli/releases/tag/v1.7.0
  * https://github.com/cli/cli/releases/tag/v1.6.0
  * https://github.com/cli/cli/releases/tag/v1.5.0
* Fri Jan 22 2021 chris@computersalat.de
- fix build for SLES12
* Tue Dec 15 2020 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 1.4.0
  * Add ability to view issue and pull request comment threads
  * Add management of GitHub Actions secrets
  * Set up git credentials when logging in to GitHub CLI
  * Add make install and make uninstall for POSIX systems when building from source
  * pr merge: attempt the merge even if mergeability status could not be determined
  * repo clone: enable cloning repository wikis
  * Recognize Include directives when parsing ssh config files
  * Display the new release notice only once per 24 hours
* Thu Dec 10 2020 Emily Roberts <nopeinomicon@posteo.net>
- Fix app not showing the correct version
- Install readme and license files
* Thu Dec 10 2020 Martin Pluskal <mpluskal@suse.com>
- Build and install manpages as well
* Wed Dec  9 2020 Emily Roberts <nopeinomicon@posteo.net>
- Use source specified at Source0 URL
- Switch from tar_scm to download_files for obtaining source archive
* Tue Dec  8 2020 Emily Roberts <nopeinomicon@posteo.net>
- Simplify BuildRequires
* Mon Dec  7 2020 Emily Roberts <nopeinomicon@posteo.net>
- Revert back to tar_scm service for submission to openSUSE:Factory
* Mon Dec  7 2020 nopeinomicon@posteo.net
- Update to version 1.3.1:
  * Allow interactive `pr create` even if we failed to look up commits
  * AskStubber now throws a more descriptive error when stubs do not match
  * Make MetadataSurvey testable by accepting an interface
  * Ensure efficient resolving of `issue/pr create` metadata to GraphQL IDs
  * don't reset previously added metadata
  * Prompt: avoid resetting PR/issue metadata if no option is selected
  * Fix "Continue in browser" for `pr create` coming from forks
  * Fix browser URL test on Windows
  * Fix respecting chosen action in interactive `issue create`
  * Properly check env auth tokens in CheckAuth
  * Delete an error message that is not useful (and had a typo)
  * Document that reviewers can be teams (gh#cli/cli#2465)
  * Bump AlecAivazis/survey
  * Sort latest PRs first when looking up PRs for a branch
* Wed Dec  2 2020 Emily Roberts <nopeinomicon@posteo.net>
- Reinstated and fixed obs_scm service for source control
- Fixed build for openSUSE Leap
* Mon Nov 30 2020 Emily Roberts <nopeinomicon@posteo.net>
- Return to tar_scm due to breakages with obs_scm service
* Wed Nov 25 2020 nopeinomicon@posteo.net
- Switch from tar_scm to obs_scm service
- Update to version 1.3.0:
  * Warn termux users with older Android versions (gh#cli/cli#2467)
  * no shorthand for --recover
  * switch to recover instead of resubmit
  * linter appeasement
  * use TempFile though the testing is gross
  * fix dumb test
  * preserve and restore issue/pr input on failure
  * add IOStreams.ReadUserFile
  * spelling: unmatched
  * spelling: template
  * spelling: settings
  * spelling: response
  * spelling: nonexistent
  * spelling: error
  * spelling: dunno
  * spelling: dismissed
  * spelling: deprecated
  * spelling: chestnuts
  * spelling: beginning
  * match parent repo protocol when forking (gh#cli/cli#2434)
  * respect GH_HOST when resolving remotes (gh#cli/cli#2301)
  * Add "reference" help topic (gh#cli/cli#2223)
  * Implement --web for gh pr checks (gh#cli/cli#2146)
  * Downgrade survey to v2.1.1
  * fix missing import
  * Support for --web when using gist create (gh#cli/cli#2263)
  * Add a command to delete a gist (gh#cli/cli#2265)
  * fix survey invocation
  * Fix USAGE help for some commands
  * add empty line between functions
  * Generate correct URL when branch option is passed in
  * add Draft to issue state
  * use NewIssueState
  * get everything working
  * stop using Defaults struct
  * stop using string pointer
  * WIP works, probably some title/body input edge cases
  * use named output param
  * Fix typos
  * Empty auth token env variables are equal to being unset
  * cleanup
  * Add support for GH_TOKEN and GH_ENTERPRISE_TOKEN
  * Consistently print commands in DEBUG mode
* Sun Nov 15 2020 Emily Roberts <nopeinomicon@posteo.net>
- Clean up .spec file
* Thu Nov 12 2020 nopeinomicon@posteo.net
- Update to version 1.2.1:
  * Fix git executable name for Windows in tests
  * Improve error message when git isn't found
  * Omit the full path of a command in DEBUG mode
  * Ensure that only PATH is searched when shelling out to external commands
  * Bump golang.org/x/text
  * Bump golang.org/x/crypto
  * Bump shurcooL/githubv4
  * Bump muesli/termenv
  * Bump mattn/go-colorable
  * Bump AlecAivazis/survey
  * Fix `truncateLabels` for empty values
  * Ensure parentheses are preserved after truncating labels in table view
  * Render links as absolute URLs in `repo view` (gh#cli/cli#2363)
  * Add Gentoo instructions to install the package (gh#cli/cli#2389)
  * Show MousetrapHelpText when double-clicking gh.exe
  * Small cleanup
  * Make markdown:generate annotation a markdown generation override for hidden commands
  * Generate markdown for help topics
  * Refactor help topics to include short message
  * Extract repeated code to util function
  * improve error message
  * Refactor regexp writer
  * Add multiple writes test
  * Use custom scanLines function for RegexWriter
  * Fix up regex to escape dot in URL
  * Address PR comments
  * Filter out unwanted stderr output during git push commands
  * new packages for get and set subcommands
  * Export type ConfigOption and group InvalidValueError code
  * Refactor config command
  * Cleanup duplicate config options
  * move cobra mutation and document it
  * Update install_linux.md
  * more iostreams passing
  * try passing iostreams around instead of writer+colorscheme
  * use shared color function
  * favor SuccessIcon
  * Use slice and make both status lines the size of the terminal width.
  * Use terminal width for the status line
  * port entirely to ColorScheme
  * added extra notes
  * Better tests for clone argument parsing
  * added Snap installation docs
  * Simplify checks test
  * add message on `pr checks` returns no CI with non-empty PR
  * Fetch all issue labels
  * Update triage.md
  * link to aliases
  * :nail_care: code style
  * :nail_care: simplify `sortPullRequestsByState`
  * PullRequestForBranch: fix outdated error message
  * Allow PullRequestForBranch to search in closed pull requests
  * Mention winget as an install option in README (gh#cli/cli#2272)
  * Small releasing docs cleanup
  * Update triage.md
  * Clean up and refactor unused doc generation code
  * Remove SEE ALSO from markdown docs generation
  * Remove Cobra autogenerated string from docs generation
  * Internalize doc generation from Cobra
  * Print friendly error when "gh repo clone" is missing required argument
  * removed runtime compare for windows The MousttrapHelpText will only be validated in cobra when running on windows.
  * run gh commands from explorer.exe
* Tue Nov 10 2020 Emily Roberts <nopeinomicon@posteo.net>
- Initial package version
